pub enum RouteResult {
Matched(String, String, Arc<dyn RefractiumProtocol>),
Fallback(String),
Discarded,
}Expand description
Result of a routing attempt.
Variants
Matched(String, String, Arc<dyn RefractiumProtocol>)
A matching protocol was found and routed to a backend.
Fallback(String)
No matching protocol was found, but traffic was routed to the fallback.
Discarded
Protocol was identified but no route or healthy fallback is available.