Protocol implementations and identification logic. Protocol identification and registry logic.
This module provides the infrastructure for identifying different protocols based on the initial data received (magic bytes, SNI, etc.).
Modules
- dns
- DNS protocol identification. DNS protocol identification logic.
- ftp
- FTP protocol identification. FTP protocol identification logic.
- http
- HTTP protocol identification. HTTP protocol identification logic.
- https
- HTTPS protocol identification. HTTPS protocol identification logic.
- ssh
- SSH protocol identification. SSH protocol identification logic.
Structs
- Dynamic
Protocol - A simple protocol identification implementation based on string patterns.
- Protocol
Match - A match result for a protocol identification attempt.
- Protocol
Registry - A registry for storing and querying protocol identification logic.
Traits
- Refractium
Protocol - A trait for protocol identification logic.